function where = searchPath(what, switches)
%SEARCHPATH Searches the system path for executables
%   SEARCHPATH E returns the path to the executable E if it exist anywhere
%   in the system path.
%
%   P = SEARCHPATH(E) returns the results of SEARCHPATH in the string P.  P
%   will contain the path to the executable E.  You must use the functional
%   form of SEARCHPATH when there is an output argument.
%
%   SEARCHPATH E -ALL returns the paths to all executables with the name
%   E.
%
%   W = SEARCHPATH(E, '-all') returns the results of the multiple search
%   version of SEARCHPATH in the cell array W.  W will contain the path
%   strings normally printed to the screen.
%
%   Windows executables must end in .EXE for searchPath to find them,
%   however you should not put a .EXE on your search.
%
%   Examples:
%       searchPath notepad
%       notepadPath = searchPath('notepad')
%       searchPath notepad -all
%       allNotepadPaths = searchPath('notepad', '-all')
%       searchPath ls

%   Copyright 1984-2007 The MathWorks, Inc.

if nargin < 2
    switches = '';
end;

if (nargin == 0) || (nargin > 2) || ((nargin == 2) && ~strcmp(switches,'-all'))
    help searchPath
    return;
end;

all = strcmp(switches, '-all');
where = {};
ext = '';

if ispc
    ext = '.exe';
end;

rem = getenv('PATH');
ii=1;
while ~isempty(rem);
    [a_path, rem]=strtok(rem, pathsep); %#ok<STTOK>
    % if you want to debug, uncomment this
    % sprintf('Searching for %s', strcat(a_path,filesep,what,ext) )
    if exist(strcat(a_path, filesep, what, ext), 'file');
        if ~all
            where = strcat(a_path, filesep, what, ext);
            rem = '';
        else
            where{ii, 1} = strcat(a_path, filesep, what, ext);
            ii = ii + 1;
        end;
    end
end

end